==> qtjambi-qt3dinput-5.15.13-sources.jar: io/qt/qt3d/input/QInputChord.java <==
package io.qt.qt3d.input;


/**
 * <p>Represents a set of QAbstractActionInput's that must be triggerd at once</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dinput-qinputchord.html">Qt3DInput::QInputChord</a></p>
 */
public class QInputChord extends io.qt.qt3d.input.QAbstractActionInput
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QInputChord.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputchord.html#timeout-prop">Qt3DInput::QInputChord::timeoutChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="timeout")
    public final Signal1<@io.qt.QtPrimitiveType Integer> timeoutChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QInputChord(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QInputChord() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputchord.html#QInputChord">Qt3DInput::QInputChord::QInputChord(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QInputChord(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QInputChord instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputchord.html#addChord">Qt3DInput::QInputChord::addChord(Qt3DInput::QAbstractActionInput*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addChord(io.qt.qt3d.input.QAbstractActionInput input){
        addChord_native_Qt3DInput_QAbstractActionInput_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(input));
    }
    
    @io.qt.QtUninvokable
    private native void addChord_native_Qt3DInput_QAbstractActionInput_ptr(long __this__nativeId, long input);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputchord.html#chords">Qt3DInput::QInputChord::chords()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QVector<io.qt.qt3d.input.QAbstractActionInput> chords(){
        return chords_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QVector<io.qt.qt3d.input.QAbstractActionInput> chords_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputchord.html#removeChord">Qt3DInput::QInputChord::removeChord(Qt3DInput::QAbstractActionInput*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeChord(io.qt.qt3d.input.QAbstractActionInput input){
        removeChord_native_Qt3DInput_QAbstractActionInput_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(input));
    }
    
    @io.qt.QtUninvokable
    private native void removeChord_native_Qt3DInput_QAbstractActionInput_ptr(long __this__nativeId, long input);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputchord.html#setTimeout">Qt3DInput::QInputChord::setTimeout(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="timeout")
    public final void setTimeout(int timeout){
        setTimeout_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), timeout);
    }
    
    private native void setTimeout_native_int(long __this__nativeId, int timeout);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dinput-qinputchord.html#timeout-prop">Qt3DInput::QInputChord::timeout()const</a></p>
     */
    @io.qt.QtPropertyReader(name="timeout")
    @io.qt.QtUninvokable
    public final int timeout(){
        return timeout_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int timeout_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QInputChord(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QInputChord(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QInputChord instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3dinput-6.3.0-sources.jar: io/qt/qt3d/input/QInputChord.java <==
package io.qt.qt3d.input;


/**
 * <p>Represents a set of QAbstractActionInput's that must be triggerd at once</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3dinput-qinputchord.html">Qt3DInput::QInputChord</a></p>
 */
public class QInputChord extends io.qt.qt3d.input.QAbstractActionInput
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QInputChord.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputchord.html#timeout-prop">Qt3DInput::QInputChord::timeoutChanged(int)</a></p>
     */
    @io.qt.QtPropertyNotify(name="timeout")
    public final Signal1<@io.qt.QtPrimitiveType Integer> timeoutChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QInputChord(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QInputChord() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputchord.html#QInputChord">Qt3DInput::QInputChord::QInputChord(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QInputChord(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QInputChord instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputchord.html#addChord">Qt3DInput::QInputChord::addChord(Qt3DInput::QAbstractActionInput*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void addChord(io.qt.qt3d.input.QAbstractActionInput input){
        addChord_native_Qt3DInput_QAbstractActionInput_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(input));
    }
    
    @io.qt.QtUninvokable
    private native void addChord_native_Qt3DInput_QAbstractActionInput_ptr(long __this__nativeId, long input);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputchord.html#chords">Qt3DInput::QInputChord::chords()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.qt3d.input.QAbstractActionInput> chords(){
        return chords_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.qt3d.input.QAbstractActionInput> chords_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputchord.html#removeChord">Qt3DInput::QInputChord::removeChord(Qt3DInput::QAbstractActionInput*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void removeChord(io.qt.qt3d.input.QAbstractActionInput input){
        removeChord_native_Qt3DInput_QAbstractActionInput_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(input));
    }
    
    @io.qt.QtUninvokable
    private native void removeChord_native_Qt3DInput_QAbstractActionInput_ptr(long __this__nativeId, long input);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputchord.html#setTimeout">Qt3DInput::QInputChord::setTimeout(int)</a></p>
     */
    @io.qt.QtPropertyWriter(name="timeout")
    public final void setTimeout(int timeout){
        setTimeout_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), timeout);
    }
    
    private native void setTimeout_native_int(long __this__nativeId, int timeout);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3dinput-qinputchord.html#timeout-prop">Qt3DInput::QInputChord::timeout()const</a></p>
     */
    @io.qt.QtPropertyReader(name="timeout")
    @io.qt.QtUninvokable
    public final int timeout(){
        return timeout_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int timeout_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QInputChord(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QInputChord(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QInputChord instance, QDeclarativeConstructor constructor);
    
}
